Crate luct_store

Crate luct_store 

Collection of implementations of different Stores

Structs

FilesystemStore
Implementation of Store that is backed by a directory.
LastValCacheStore
A OrderedStore that caches the last value in memory
LruCacheStore
A Store implementation that wraps an inner Store and ads an LRU (least-recently-used) cache around it.

Enums

StoreSwitch
Store implementation that switches between two different inner Stores.

Traits

StringStoreKey
Indicates, that a key can be serialized as a String.
StringStoreValue
Indicates, that a value can be serialized as a String.