StoreSwitch

Enum StoreSwitch 

pub enum StoreSwitch<A, B> {
    A(A),
    B(B),
}
Store implementation that switches between two different inner Stores.

This can be used, if you want to switch at runtime between the Stores A and B,

Variants



A(A)



B(B)