FilesystemStore

Struct FilesystemStore 

pub struct FilesystemStore<K, V> { /* private fields */ }
Implementation of Store that is backed by a directory.

Description

FilesystemStore used a directory named after the store and stores the keys as files. It requires both StringStoreKey for keys and StringStoreValue for values, since it stores the values as Strings as well.

This implementation is not efficient in any way. It is fast enough for CLI usage, since the amount of data processed there is relatively small. Also, storing data as Stings in files makes debugging and understanding what data has been stored very easy.

Searching through the store is done by scanning through the directory, which is very slow.

Caution

There is no locking or checking that each path is instanciated only once. You must be careful not to instanciate two stores at the same location.

Also starting a program that uses the store twice may load to problems. This is used mainly for simple applications. You may need a database for more complex applications.

Implementations

Source

impl<K, V> FilesystemStore<K, V>

pub fn new(path: PathBuf) -> FilesystemStore<K, V>

Create a new FilesystemStore, at the path