LruCacheStore

Struct LruCacheStore 

pub struct LruCacheStore<S>
where S: StoreBase,
{ /* private fields */ }
A Store implementation that wraps an inner Store and ads an LRU (least-recently-used) cache around it.

The cache is write-through, i.e. there is no speedup when writing to the store. Furthermore, the implementation is not Send or Sync. A common patthern would be to have one LruCacheStore per thread wrapping an inner store.

Implementations

Source

impl<S> LruCacheStore<S>
where S: StoreBase<Key: Hash + Eq>,

pub fn new(store: S, caps: usize) -> Self