StringStoreValue

Trait StringStoreValue 

pub trait StringStoreValue:
    Clone
    + Send
    + Eq
    + 'static {
    // Required methods
    fn serialize_value(&self) -> String;
    fn deserialize_value(value: &str) -> Option<Self>;
}
Indicates, that a value can be serialized as a String.

Some Store implementations need to internally store values as a String.

These implementations need to restrict their value type to StringStoreValue.

Required Methods

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl StringStoreValue for ()

Source

impl StringStoreValue for SignedCertificateTimestamp

Source

impl StringStoreValue for SignedTreeHead

Source

impl StringStoreValue for String

Implementors