Collection of implementations of different Stores
Structs
- Filesystem
Store - Implementation of
Storethat is backed by a directory. - Last
ValCache Store - A
OrderedStorethat caches thelastvalue in memory - LruCache
Store - A
Storeimplementation that wraps an innerStoreand ads an LRU (least-recently-used) cache around it.
Enums
- Store
Switch Storeimplementation that switches between two different innerStores.
Traits
- String
Store Key - Indicates, that a key can be serialized as a
String. - String
Store Value - Indicates, that a value can be serialized as a
String.