Crate luct_store

Crate luct_store 

Collection of implementations of different Stores

Structs

FilesystemStore
Implementation of Store that is backed by a directory.

Enums

StoreSwitch
Store implementation that switches between two different inner Stores.

Traits

StringStoreKey
Indicates, that a key can be serialized as a String.
StringStoreValue
Indicates, that a value can be serialized as a String.