pub trait StringStoreValue:
Clone
+ Send
+ Eq
+ 'static {
// Required methods
fn serialize_value(&self) -> String;
fn deserialize_value(value: &str) -> Option<Self>;
}Expand description
Indicates, that a value can be serialized as a String.
Some Store implementations need to internally store values
as a String.
These implementations need to restrict their value type to StringStoreValue.
Required Methods
fn serialize_value(&self) -> String
fn deserialize_value(value: &str) -> Option<Self>
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.